@@ -6,7 +6,7 @@ subst - Greple module for text search and substitution
 
 =head1 VERSION
 
-Version 2.17
+Version 2.18
 
 =head1 SYNOPSIS
 
@@ -274,12 +274,11 @@ it under the same terms as Perl itself.
 =cut
 
 
+use v5.14;
 package App::Greple::subst;
 
-our $VERSION = '2.17';
+our $VERSION = '2.18';
 
-use v5.14;
-use strict;
 use warnings;
 use utf8;
 use open IO => ':utf8';
@@ -350,7 +349,7 @@ my $current_file;
 my $contents;
 my @subst_diffcmd;
 my $ignorechar_re;
-my $dict = new App::Greple::subst::Dict;
+my $dict = App::Greple::subst::Dict->new;
 
 sub debug {
     $debug = 1;
@@ -489,7 +488,7 @@ sub subst_show_stat {
 		my $index = $key eq $to ? $i * 2 + 1 : $i * 2;
 		printf(" %s(%s)",
 		       main::index_color($index, $key),
-		       colorize($key eq $to ? 'B' : 'RD', $hash->{$key})
+		       colorize($key eq $to ? 'DB' : 'DR', $hash->{$key})
 		    );
 	    }
 	}
@@ -660,7 +659,7 @@ sub subst_diff {
 
     if ($remember_data) {
 	use IO::Pipe;
-	$io = new IO::Pipe;
+	$io = IO::Pipe->new;
 	my $pid = fork() // die "fork: $!\n";
 	if ($pid == 0) {
 	    $io->writer;
